// $Id: PagePrevious.java 14099 2011-10-20 15:46:41Z mike $

package org.faceless.pdf2.viewer2.feature;

import org.faceless.pdf2.viewer2.*;
import org.faceless.pdf2.PDFPage;
import org.faceless.pdf2.PDF;
import javax.swing.*;

/**
 * Create a button that jumps to the previous page.
 *
 * <span class="featurename">The name of this feature is <span class="featureactualname">PagePrevious</span></span>
 * <p><i>This code is copyright the Big Faceless Organization. You're welcome to use, modify and distribute it in any form in your own projects, provided those projects continue to make use of the Big Faceless PDF library.</i></p>
 * @since 2.8
 */
public class PagePrevious extends ViewerWidget implements DocumentPanelListener
{
    public PagePrevious() {
        super("PagePrevious");
        setButton("Navigation.ltr", "resources/icons/PreviousPage.png", "PDFViewer.tt.PagePrevious");
        setMenu("View\tGoTo\tPreviousPage");
    }

    public void action(ViewerEvent event) {
        DocumentPanel docpanel = event.getDocumentPanel();
        PDFPage page = docpanel.getViewport().getRenderingPage();
        int pagenumber = page==null ? 0 : page.getPageNumber() - 1;
        if (pagenumber > 0) {
            event.getDocumentPanel().setPageNumber(pagenumber - 1);
        }
    }

    public void initialize(PDFViewer viewer) {
        super.initialize(viewer);
        viewer.addDocumentPanelListener(this);
    }

    public void documentUpdated(DocumentPanelEvent event) {
        if (event.getType()=="pageChanged" || event.getType()=="activated") {
            boolean enabled = event.getDocumentPanel().getPDF()!=null && event.getDocumentPanel().getPageNumber() > 0;
            event.getDocumentPanel().getViewer().getNamedComponent("ButtonPagePrevious").setEnabled(enabled);
            event.getDocumentPanel().getViewer().getNamedComponent("MenuPagePrevious").setEnabled(enabled);
        }
    }
}
